@@ -491,6 +491,10 @@ class Plugin(plugin.PluginBase):
             ohostedcons.StorageEnv.LUN_ID,
             None
         )
+        self.environment.setdefault(
+            ohostedcons.StorageEnv.DISCARD_SUPPORT,
+            False
+        )
 
     @plugin.event(
         stage=plugin.Stages.STAGE_CLOSEUP,
@@ -566,7 +570,9 @@ class Plugin(plugin.PluginBase):
             lunid = self.environment[
                 ohostedcons.StorageEnv.LUN_ID
             ]
-            discard = True
+            discard = self.environment[
+                ohostedcons.StorageEnv.DISCARD_SUPPORT
+            ]
 
             if domain_type is None:
                 domain_type = self.dialog.queryString(
@@ -605,11 +611,19 @@ class Plugin(plugin.PluginBase):
                 domain_type == ohostedcons.DomainTypes.NFS or
                 domain_type == ohostedcons.DomainTypes.GLUSTERFS
             ):
+                path_test = '.+:/.+'
                 if storage_domain_connection is None:
                     storage_domain_connection = self._query_connection_path()
                 storage_domain_det = storage_domain_connection.split(':')
-                if len(storage_domain_det) != 2:
-                    msg = _('Invalid connection path')
+                if (
+                    not re.match(path_test, storage_domain_connection) or
+                    len(storage_domain_det) != 2
+                ):
+                    msg = _(
+                        'Invalid connection path: {p}'
+                    ).format(
+                        p=storage_domain_connection,
+                    )
                     self.logger.error(msg)
                     if not interactive:
                         raise RuntimeError(msg)
@@ -650,7 +664,6 @@ class Plugin(plugin.PluginBase):
                                 portal=iscsi_portal,
                                 port=iscsi_port,
                             )
-                        storage_domain_address = iscsi_portal.split(',')[0]
                     except RuntimeError as e:
                         self.logger.error(_('Unable to get target list'))
                         if not interactive:
@@ -678,6 +691,8 @@ class Plugin(plugin.PluginBase):
                             raise e
                         continue
 
+                storage_domain_address = iscsi_portal.split(',')[0]
+
             elif domain_type == ohostedcons.DomainTypes.FC:
                 if lunid is None:
                     try:
